@@ -299,6 +299,25 @@ void swoole_http_parse_cookie(zval *zarray, const char *at, size_t length, bool
 
             j = i + 1;
             state = 1;
+        } else if (state <= 0 && *_c == ';') {
+            klen = i - j + 1;
+            if (klen >= SW_HTTP_COOKIE_KEYLEN) {
+                swoole_warning("cookie[%.*s...] name length %d is exceed the max name len %d",
+                       8,
+                       (char *) at + j,
+                       klen,
+                       SW_HTTP_COOKIE_KEYLEN);
+                return;
+            }
+            memcpy(keybuf, (char *) at + j, klen - 1);
+            keybuf[klen - 1] = 0;
+
+            if (klen > 1) {
+                add_assoc_stringl_ex(zarray, keybuf, klen - 1, ZEND_STRL(""));
+            }
+
+            j = i + 1;
+            state = -1;
         } else if (state == 1 && *_c == ';') {
             vlen = i - j;
             if (vlen >= SW_HTTP_COOKIE_VALLEN) {
