@@ -68,12 +68,22 @@ typedef struct {
 	int                   method;
 } php_curl_progress, php_curl_fnmatch, php_curlm_server_push;
 
+typedef struct {
+	zval                  func_name;
+	zend_fcall_info_cache fci_cache;
+} php_curl_callback;
+
 typedef struct {
 	php_curl_write    *write;
 	php_curl_write    *write_header;
 	php_curl_read     *read;
 	zval               std_err;
 	php_curl_progress *progress;
+#if PHP_VERSION_ID >= 80200
+#if LIBCURL_VERSION_NUM >= 0x072000
+	php_curl_callback  *xferinfo;
+#endif
+#endif
 #if LIBCURL_VERSION_NUM >= 0x071500 /* Available since 7.21.0 */
 	php_curl_fnmatch  *fnmatch;
 #endif
@@ -214,8 +224,13 @@ static inline php_curlsh *curl_share_from_obj(zend_object *obj) {
 
 #define Z_CURL_SHARE_P(zv) curl_share_from_obj(Z_OBJ_P(zv))
 void curl_multi_register_class(const zend_function_entry *method_entries);
+
+#if PHP_VERSION_ID < 80200
 int swoole_curl_cast_object(zend_object *obj, zval *result, int type);
 #else
+zend_result swoole_curl_cast_object(zend_object *obj, zval *result, int type);
+#endif
+#else
 #define Z_CURL_P(zv)     swoole_curl_get_handle(zv)
 #endif /* PHP8 end */
 
